<?php
// Custom installation profile generated by the UberInstaller (http://install.ubercart.org/)

/**
 * Return an array of the modules to be enabled when this profile is installed.
 *
 * @return
 *  An array of modules to be enabled.
 */
function ubercart_deluxe_profile_modules() {
  return array('block','filter','node','system','user','watchdog','color','contact','help','menu','path','statistics','taxonomy','admin_menu','admin_menu_dropdown','content','fieldgroup','googleanalytics','imagefield','tapir','thickbox','token','uc_store','workflow_ng','ubrowser','uc_order','uc_product','uc_cart','uc_catalog','imagecache');
}

/**
 * Return a description of the profile for the initial installation screen.
 *
 * @return
 *   An array with keys 'name' and 'description' describing this profile.
 */
function ubercart_deluxe_profile_details() {
  return array(
    'name' => 'Ubercart 1.0 (Deluxe)',
    'description' => 'The Ubercart 1.0 Deluxe package contains Ubercart, its required modules, additional modules for e-commerce tracking and out-of-the-box image support, and other modules helpful for e-commerce sites.'
  );
}

/**
 * Perform any final installation tasks for this profile.
 *
 * @return
 *   An optional HTML string to display to the user on the final installation
 *   screen.
 */
function ubercart_deluxe_profile_final() {
  //Create file directory
  mkdir('files');

  // Insert default user-defined node types into the database.
  $types = array(
    array(
      'type' => 'page',
      'name' => st('Page'),
      'module' => 'node',
      'description' => st('If you want to add a static page, like a contact page or an about page, use a page.'),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
    ),
    array(
      'type' => 'story',
      'name' => st('Story'),
      'module' => 'node',
      'description' => st('Stories are articles in their simplest form: they have a title, a teaser and a body, but can be extended by other modules. The teaser is part of the body too. Stories may be used as a personal blog or for news articles.'),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
    ),
  );
  foreach ($types as $type) {
    $type = (object) _node_type_set_defaults($type);
    node_type_save($type);
  }

  // Comments disabled
  variable_set('site_name', "Ubercart");

  // Comments disabled
  variable_set('comment_page', COMMENT_NODE_DISABLED);
  
  // Don't display date and author information for page nodes by default.
  $theme_settings = variable_get('theme_settings', array());
  $theme_settings['toggle_node_info_page'] = FALSE;
  variable_set('theme_settings', $theme_settings);

  //Create Store Admin/Shopping Cart/User Guide Blocks
  db_query("INSERT INTO {blocks} (`module`,`delta`,`theme`,`status`,`weight`,`region`) VALUES ('uc_cart', 0, 'garland', 1, -9, 'left') ");
  db_query("INSERT INTO {blocks} (`module`,`delta`,`theme`,`status`,`weight`,`region`) VALUES ('uc_store', 0, 'garland', 1, -10, 'left') ");
  db_query("INSERT INTO {blocks} (`module`, `delta`, `theme`, `status`, `weight`, `region`) VALUES ('block', 1, 'garland', 1, -8, 'right')");
  db_query("INSERT INTO {blocks_roles} (`module`, `delta`, `rid`) VALUES ('block', '1', 2)");
  db_query("INSERT INTO {boxes} (`bid`, `body`, `info`, `format`) VALUES (1, '".st('View the <a target="_blank" href="http://www.ubercart.org/docs/user">Ubercart User Guide</a> for more information on configuring Ubercart.')."', '".st('User Guide')."', 1)");
  
  //Rebuild Menu and Node Types
  menu_rebuild();  
  node_types_rebuild();
}